@@ -1,4 +1,4 @@
-verifyCoreClass <- function(test, pred, verbose)
+comparePredict <- function(valueName, pred, continue)
 {
 	stored <- c(
 	 188,230,949,934,402,155,195,828,186,970,178, 94,898,320,846,122,644,924,812,911,948,204,301, 70,646,740,292,878, 26,
@@ -37,15 +37,25 @@ verifyCoreClass <- function(test, pred, verbose)
 	 939,919,122, 45,681,879,545,885,603, 44, 36,131,514,930, 51,762, 78, 13,873,604, 39,126,993,241,125,963,210,709, 42,
 	 184,280,506, 87,229,949,957,370, 97,420,883,262,141,944)/1000
 
-	#stored[1:20] <- 0.5 # simulate an error
+	#stored[3*(10:30)] <- 0.6 # simulate an error
 
     sdappr <- 0.095*(stored*(1 - stored))^0.61
 	out <- pred$probabilities[, 2]
 	err <- (out - stored)/sdappr
 	curr <- mean(err^2)
-	ok <- curr < 2
-	outputResult("verifyCoreClass", ok, verbose, paste("value", curr))
-	ok
+	res <- curr < 2
+    if (!res) {
+		cat("Comparison FAILED for ", valueName, "\n", sep="")
+        cat("mean(error^2) =", curr, "\n")
+        ind <- order(err, decreasing=TRUE)[1:10]
+        print(cbind(ind, stored=stored[ind], obtained=out[ind], error=err[ind]))
+		if (continue) {
+			cat("comparison FAILED\n")
+		} else {
+			stop("comparison FAILED")
+		}
+    }
+	res
 }
 
 cmp.table <- function(a, b)
@@ -59,150 +69,174 @@ cmp.table <- function(a, b)
     }
 }
 
-verifyMEval <- function(pred, cl, mEval)
+compareMEval <- function(valueName, pred, cl, mEval, continue)
 {
     accuracy <- mean(pred$class == cl)
-    res1 <- accuracy==accuracy
+    res1 <- accuracy == mEval$accuracy
     aux.pred.mat <- table(cl, pred$class)
     res2 <- cmp.table(mEval$predictionMatrix, aux.pred.mat)
-    all(c(res1, res2))
-}
-
-outputResult <- function(testName, status, verbose, failMessage=NULL)
-{
-    if (!all(status)) {
-		if (is.null(failMessage)) {
-			failMessage <- ""
+    res <- all(res1, res2)
+    if (!res) {
+		cat("Comparison FAILED for ", valueName, "\n", sep="")
+        cat("accuracy =", accuracy, "\n")
+        cat("mEval$accuracy =", mEval$accuracy, "\n")
+        cat("aux.pred.mat\n")
+        print(aux.pred.mat)
+        cat("mEval$predictionMatrix\n")
+        print(mEval$predictionMatrix)
+		if (continue) {
+			cat("comparison FAILED\n")
 		} else {
-			failMessage <- paste(" (", failMessage, ")", sep="")
+			stop("comparison FAILED")
 		}
-		cat(testName, " FAILED", failMessage, "\n", sep="")
-		if (verbose <= 0)
-			stop("test failed")
-	}
+    }
+    res
 }
 
-approxComp <- function(valueName, obtained, stored, continue)
+compareClass <- function(valueName, value1, value2, continue)
 {
-	obtained <- unname(obtained)
-    res <- isTRUE(all.equal(obtained, stored))
+    res <- identical(value1, value2)
 	if (!res) {
 		cat("Comparison FAILED for ", valueName, "\n", sep="")
-		cat("stored\n")
-		print(stored)
-		cat("difference\n")
-		print(obtained - stored)
-		cat("obtained\n")
-		print(obtained)
+        print(table(value1, value2))
 		if (continue) {
-			warning("comparison FAILED for ", valueName)
+			cat("comparison FAILED\n")
 		} else {
-			stop("Comparison FAILED for ", valueName)
+			stop("Comparison FAILED")
 		}
 	}
 	res
 }
 
-asTxt <- function(ok)
+compareApprox <- function(valueName, value1, value2, tolerance, continue)
 {
-	if (all(ok)) {
-		"OK"
-	} else {
-		"FAIL"
+    res <- max(abs(value1 - value2)) <= tolerance
+	if (!res) {
+		cat("Comparison FAILED for ", valueName, "\n", sep="")
+		cat(deparse(substitute(value1)), "\n")
+		print(value1)
+		cat("difference\n")
+		print(value2 - value1)
+		cat(deparse(substitute(value2)), "\n")
+		print(value2)
+		if (continue) {
+			cat("comparison FAILED\n")
+		} else {
+			stop("Comparison FAILED")
+		}
 	}
+	res
 }
 
-testCoreClass <- function(verbose=1)
+testCoreClass <- function(continue=TRUE)
 {
 	ncases <- 1000
-	RNGversion("2.9.2")
+    RNGkind("Mersenne-Twister")
 	set.seed(12345)
 	train <- classDataGen(ncases)
 	test <- classDataGen(ncases)
     model <- CoreModel(class ~ ., train, model="rf", minNodeWeightRF=5, minNodeWeightEst=2, rfNoTrees=100)
     pred <- predict(model, test, rfPredictClass=FALSE)
     # consistency of predict output
-    res1 <- identical(pred$class == "1", pred$probabilities[,1] >= 0.5)
-    # ROC test
-    res2 <- verifyCoreClass(test, pred, verbose)
+    res1 <- compareClass("testCoreClass/pred$class", pred$class == "2", pred$probabilities[, 2] >= 0.5, continue)
+    # compare with stored values
+    res2 <- comparePredict("testCoreClass/pred", pred, continue)
     # modelEval test
     mEval <- modelEval(model, test$class, pred$class, pred$prob)
-    res3 <- verifyMEval(pred, test$class, mEval)
-    ok <- c(res1, res2, res3)
-	outputResult("testCoreClass", ok, verbose, paste(res1, res2, res3))
-	all(ok)
+    res3 <- compareMEval("testCoreClass/modelEval", pred, test$class, mEval, continue)
+    all(res1, res2, res3)
 }
 
 testCoreAttrEval <- function(continue=TRUE)
 {
     ncases <- 1000
-    RNGversion("2.9.2")
+    RNGkind("Mersenne-Twister")
     set.seed(0)
     train <- classDataGen(ncases)
-    estReliefF <- attrEval(class ~ ., train, estimator="ReliefFexpRank")
-    comp1<-c(0.050083407,0.078033329,0.042187049,0.034625011,0.064074820,0.057376281,
+    set.seed(0)
+    estReliefF1 <- attrEval(class ~ ., train, estimator="ReliefFexpRank", maxThreads=1)
+    set.seed(0)
+    estReliefF0 <- attrEval(class ~ ., train, estimator="ReliefFexpRank", maxThreads=0)
+    resA1 <- compareApprox("testCoreAttrEval/estReliefF/threads", estReliefF0, estReliefF1, 1e-12, continue)
+    stored <-c(0.050083407,0.078033329,0.042187049,0.034625011,0.064074820,0.057376281,
              0.007454174,0.136318607,0.109862236,0.001486706)
-    res1 <- approxComp("testCoreAttrEval/estReliefF", estReliefF, comp1, continue)
-    estMdl <- attrEval(class ~ ., train, estimator="MDL",minNodeWeightEst=5)
-    comp2 <- c(0.0430367148311, 0.0726888549425, 0.0315160729442, 0.0280291538191, 0.0581082266459,
+    resA2 <- compareApprox("testCoreAttrEval/estReliefF/stored", stored, estReliefF0, 1e-9, continue)
+    set.seed(0)
+    estMdl1 <- attrEval(class ~ ., train, estimator="MDL", minNodeWeightEst=5, maxThreads=1)
+    set.seed(0)
+    estMdl0 <- attrEval(class ~ ., train, estimator="MDL", minNodeWeightEst=5, maxThreads=0)
+    resB1 <- compareApprox("testCoreAttrEval/estMdl/threads", estMdl0, estMdl1, 0, continue)
+    stored <- c(0.0430367148311, 0.0726888549425, 0.0315160729442, 0.0280291538191, 0.0581082266459,
             0.0413914181947, -0.0095497415727, 0.1069959122855, 0.1045578033412, 0.0008384525753)
-    res2 <- approxComp("testCoreAttrEval/estMdl", estMdl, comp2, continue)
-    all(res1, res2)
+    resB2 <- compareApprox("testCoreAttrEval/estMdl/stored", stored, estMdl0, 1e-9, continue)
+    all(resA1, resA2, resB1, resB2)
 }
 
-testCoreReg <- function(verbose=1)
+testCoreReg <- function(continue=TRUE)
 {
     ncases <- 1000
-    RNGversion("2.9.2")
+    RNGkind("Mersenne-Twister")
     set.seed(0)
     train <- regDataGen(ncases)
     test<- regDataGen(ncases)
-    model <- CoreModel(response~., train, model="regTree", modelTypeReg=5, minNodeWeightEst=1,minNodeWeightTree=5)
+    model <- CoreModel(response~., train, model="regTree", modelTypeReg=5, minNodeWeightEst=1, minNodeWeightTree=5)
     pred <- predict(model, test)
     # Model evaluation
     mEval <- modelEval(model, test[["response"]], pred)
-    comp1<-c(0.6964669, 0.650204, 0.4437024, 0.6416557) # for ModelTypeReg=5, for modelTypeReg = 3: c(0.7326231, 0.7194654, 0.4705813, 0.6805264) 
-    res1 <- isTRUE(all.equal(c(mEval$MSE,mEval$RMSE,mEval$MAE,mEval$RMAE), comp1,tolerance=1e-6))
+    stored <- c(0.6964669, 0.650204, 0.4437024, 0.6416557) # for ModelTypeReg=5, for modelTypeReg = 3: c(0.7326231, 0.7194654, 0.4705813, 0.6805264) 
+    res1 <- compareApprox("testCoreReg/mEval", stored, c(mEval$MSE,mEval$RMSE,mEval$MAE,mEval$RMAE), 1e-6, continue)
     # Attribute evaluation with RReliefFexpRank
     estReliefF <- attrEval(response~., train, estimator="RReliefFexpRank")
-    comp2<-c(0.010290964,-0.009417843,-0.024053605, -0.040329099, -0.037327744,
+    stored <- c(0.010290964,-0.009417843,-0.024053605, -0.040329099, -0.037327744,
              -0.003113488, -0.036898833,  0.012602801,  0.082472855,  0.163371230) 
-    res2 <- isTRUE(all.equal(unname(estReliefF), comp2,tolerance=1e-6))
+    res2 <- compareApprox("testCoreReg/estReliefF", stored, estReliefF, 1e-6, continue)
     # Attribute evaluation with MSEofMean
-    comp3 <- c( -0.6673072, -0.6623068, -0.7465442, -0.7448963, -0.7220145, -0.7282959,
+    stored <- c( -0.6673072, -0.6623068, -0.7465442, -0.7448963, -0.7220145, -0.7282959,
                -0.7430563, -0.7198671, -0.6793427, -0.6390350)
     estMSE <- attrEval(response~., train, estimator="MSEofMean")
-    res3 <- isTRUE(all.equal(unname(estMSE), comp3,tolerance=1e-6))
-    ok <- c(res1, res2, res3)
-	outputResult("testCoreReg", ok, verbose, paste(res1,res2,res3))
-	all(ok)
+    res3 <- compareApprox("testCoreReg/estMSE", stored, estMSE, 1e-6, continue)
+    all(res1, res2, res3)
 }
 
 
-testCoreOrdEval <- function(verbose=1) {
+testCoreOrdEval <- function(continue=TRUE)
+{
     ncases <- 1000
-    RNGversion("2.9.2")
+    RNGkind("Mersenne-Twister")
     set.seed(0)
     train <-  ordDataGen(ncases)
     estOrdEval <- ordEval(class~., train, ordEvalNoRandomNormalizers=0 )
-    comp1<-c(0.48737601443, 0.64164648910, 0.31284403670, 0.40484429066,
+    stored <- c(0.48737601443, 0.64164648910, 0.31284403670, 0.40484429066,
              0.30640535373, 0.39493899684, 0.25654450262, 0.24069352371)
-    res1 <- isTRUE(all.equal(unname(estOrdEval$reinfPosAttr), comp1))
-    comp2 <- c(0.47735849057, 0.62565320665, 0.30726515502, 0.37860861335,
+    res1 <- compareApprox("testCoreOrdEval/reinfPosAttr", stored, estOrdEval$reinfPosAttr, 2^-26, continue)
+    stored <- c(0.47735849057, 0.62565320665, 0.30726515502, 0.37860861335,
                0.27582938389, 0.35876840696, 0.25065160730, 0.24556062912)
-    res2 <- isTRUE(all.equal(unname(estOrdEval$reinfNegAttr), comp2))
-    comp3<- c(0.47951253974, 0.54837049743, 0.43117158509, 0.45156889495,
+    res2 <- compareApprox("testCoreOrdEval/reinfNegAttr", stored, estOrdEval$reinfNegAttr, 2^-26, continue)
+    stored <- c(0.47951253974, 0.54837049743, 0.43117158509, 0.45156889495,
               0.43170058641, 0.46538045438, 0.42272646060, 0.43029004614)
-    res3 <- isTRUE(all.equal(unname(estOrdEval$anchorAttr), comp3))
-    ok <- c(res1, res2, res3)
-	outputResult("testCoreOrdEval", ok, verbose)
-	all(ok)
+    res3 <- compareApprox("testCoreOrdEval/anchorAttr", stored, estOrdEval$anchorAttr, 2^-26, continue)
+    all(res1, res2, res3)
 }
 
-gener.Reg <- function(m,n)
+#gener.Reg <- function(m,n)
+#{
+#    x <- matrix(runif(m*n),nrow=m,ncol=n)
+#    data.frame(x,resp=rowSums(x))
+#}
+
+outputResult <- function(testName, status, failMessage, continue)
 {
-    x <- matrix(runif(m*n),nrow=m,ncol=n)
-    data.frame(x,resp=rowSums(x))
+    if (!all(status)) {
+        outMessage <- testName
+		if (failMessage != "") {
+			outMessage <- paste(outMessage, " (", failMessage, ")", sep="")
+		}
+		if (continue) {
+			cat("Test FAILED: ", outMessage, "\n", sep="")
+		} else {
+			stop("Test FAILED: ", outMessage)
+		}
+	}
 }
 
 singleTestNA <- function(t, x)
@@ -215,7 +249,7 @@ singleTestNA <- function(t, x)
     PACKAGE="CORElearn")$out
 }
 
-testCoreNA <- function(verbose=1)
+testCoreNA <- function(continue=TRUE)
 {
     a <- matrix(nrow=4, ncol=2)
     a[1,] <- singleTestNA(0, NA) # pass NA to CORElearn
@@ -223,19 +257,19 @@ testCoreNA <- function(verbose=1)
     a[3,] <- singleTestNA(1, 0) # use internal NAcont
     a[4,] <- singleTestNA(2, 0) # generate NaN
     ok <- a == rbind(c(1,0), c(0,1), c(1,0), c(0,1))
-	outputResult("testCoreNA", ok, verbose)
+	outputResult("testCoreNA", ok, "", continue)
 	all(ok)
 }
 
-testCoreRPORT <- function(verbose=1)
+testCoreRPORT <- function(continue=TRUE)
 {
     tmp <- .C("testRPORT", a=as.integer(2), PACKAGE="CORElearn")
     ok <- tmp$a == 1
-	outputResult("testCoreRPORT", ok, verbose, tmp$a)
+	outputResult("testCoreRPORT", ok, tmp$a, continue)
 	all(ok)
 }
 
-testCoreRand <- function(verbose=1)
+testCoreRand <- function(continue=TRUE)
 {
     n <- 10
     runif(1)
@@ -244,37 +278,46 @@ testCoreRand <- function(verbose=1)
     .Random.seed <<- state
     y <- .C("testCoreRand", as.integer(n), a=double(n), PACKAGE="CORElearn")$a
 	ok <- x == y
-	outputResult("testCoreRand", ok, verbose, paste(x[1], x[2], y[1], y[2]))
+	outputResult("testCoreRand", ok, paste(x[1], x[2], y[1], y[2]), continue)
 	all(ok)
 }
 
-allTests <- function(verbose=1,timed=FALSE)
+asTxt <- function(ok)
 {
-    t1 <- system.time(r1 <- testCoreClass(1))
+	if (all(ok)) {
+		"OK"
+	} else {
+		"FAIL"
+	}
+}
+
+allTests <- function(continue=TRUE, timed=FALSE)
+{
+    t1 <- system.time(r1 <- testCoreClass(continue))
     cat("testCoreClass()    : ", asTxt(r1), "\n")
     if (timed) cat("Elapsed", t1["elapsed"],"sec\n")
-    t2 <- system.time(r2 <- testCoreAttrEval(FALSE))
+    t2 <- system.time(r2 <- testCoreAttrEval(continue))
     cat("testCoreAttrEval() : ", asTxt(r2), "\n")
     if (timed) cat("Elapsed", t2["elapsed"],"sec\n")
-    t3 <- system.time(r3 <- testCoreReg(1))
+    t3 <- system.time(r3 <- testCoreReg(continue))
     cat("testCoreReg()      : ", asTxt(r3), "\n")
     if (timed) cat("Elapsed", t3["elapsed"],"sec\n")
-    t4 <- system.time(r4 <- testCoreOrdEval(1))
+    t4 <- system.time(r4 <- testCoreOrdEval(continue))
     cat("testCoreOrdEval()  : ", asTxt(r4), "\n")
     if (timed) cat("Elapsed", t4["elapsed"],"sec\n")
     if (timed) {
         cat("system.time() summary\n")
         print(rbind(t1, t2, t3, t4)[, 1:3])
     }
-    r5 <- testCoreNA(1)
+    r5 <- testCoreNA(continue)
     cat("testCoreNA()       : ", asTxt(r5), "\n")
-    r6 <- testCoreRPORT(1)
+    r6 <- testCoreRPORT(continue)
     cat("testCoreRPORT()    : ", asTxt(r6), "\n")
-    r7 <- testCoreRand(1)
+    r7 <- testCoreRand(continue)
     cat("testCoreRand()     : ", asTxt(r7), "\n")
-	ok <- c(r1, r2, r3, r4, r5, r6, r7)
-	outputResult("allTests", ok, verbose)
-	invisible(all(ok))
+	result <- all(r1, r2, r3, r4, r5, r6, r7)
+	outputResult("allTests", result, "", continue=FALSE)
+	invisible(result)
 }
 
 testClassPseudoRandom <- function(s, k, m)
